--[[
AdiBags - Dragonflight
by Zottelchen
version: 0.9.0
Add various Dragonflight items to AdiBags filter groups
]]

local addonName, addon = ...
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")

local L = addon.L
local MatchIDs
local Result = {}

local function AddToSet(List)
    local Set = {}
    for _, v in ipairs(List) do
        Set[v] = true
    end
    return Set
end

local function unescape(String)
    local unescaped = tostring(String)
    unescaped = gsub(unescaped, "|c........", "") -- Remove color start.
    unescaped = gsub(unescaped, "|r", "") -- Remove color end.
    -- Result = gsub(Result, "|H.-|h(.-)|h", "%1") -- Remove links.
    -- Result = gsub(Result, "|T.-|t", "") -- Remove textures.
    -- Result = gsub(Result, "{.-}", "") -- Remove raid target icons.
    return unescaped
end


 -- PreEvent
local PreEventIDs = {
199211, -- Primeval Essence
199348, -- Cloudburst Robes
199349, -- Cloudburst Slippers
199350, -- Cloudburst Mitts
199351, -- Cloudburst Hood
199352, -- Cloudburst Breeches
199353, -- Cloudburst Mantle
199354, -- Cloudburst Sash
199355, -- Cloudburst Bindings
199356, -- Dust Devil Raiment
199357, -- Dust Devil Treads
199358, -- Dust Devil Gloves
199359, -- Dust Devil Mask
199360, -- Dust Devil Leggings
199361, -- Dust Devil Epaulets
199362, -- Dust Devil Cincture
199363, -- Dust Devil Wristbands
199364, -- Cyclonic Chainmail
199365, -- Cyclonic Striders
199366, -- Cyclonic Gauntlets
199367, -- Cyclonic Cowl
199368, -- Cyclonic Kilt
199369, -- Cyclonic Spaulders
199370, -- Cyclonic Cinch
199371, -- Cyclonic Bracers
199372, -- Firestorm Chestplate
199373, -- Firestorm Stompers
199374, -- Firestorm Crushers
199375, -- Firestorm Greathelm
199376, -- Firestorm Greaves
199377, -- Firestorm Pauldrons
199378, -- Firestorm Girdle
199379, -- Firestorm Vambraces
199380, -- Cyclonic Drape
199384, -- Cloudburst Wrap
199385, -- Dust Devil Cloak
199386, -- Firestorm Cape
}



local function MatchIDs_Init(self)
    wipe(Result)

    if self.db.profile.movePreEvent then
        if self.db.profile.showcoloredCategories then
            Result["|cff0050a2PreEvent|r"] = AddToSet(PreEventIDs)
        else
            Result[unescape("|cff0050a2PreEvent|r")] = AddToSet(PreEventIDs)
        end
    end



    return Result
end

local setFilter = AdiBags:RegisterFilter("Dragonflight", 98, "ABEvent-1.0")
setFilter.uiName = "|cffA00000Dragonflight|r"
setFilter.uiDesc = "Items from the Dragonflight\n|cff50C878Filter version: 0.9.0|r"

function setFilter:OnInitialize()
    self.db = AdiBags.db:RegisterNamespace("Dragonflight", {
        profile = {
            
            movePreEvent = true,
            showcoloredCategories = true,
        }
    })
end

function setFilter:Update()
    MatchIDs = nil
    self:SendMessage("AdiBags_FiltersChanged")
end

function setFilter:OnEnable()
    AdiBags:UpdateFilters()
end

function setFilter:OnDisable()
    AdiBags:UpdateFilters()
end

function setFilter:Filter(slotData)
    MatchIDs = MatchIDs or MatchIDs_Init(self)
    for i, name in pairs(MatchIDs) do
        -- Override Method
        if MatchIDs[i]['override'] then
            slotData['loc'] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
            if slotData['loc']  and slotData['loc']:IsValid() then
                if MatchIDs[i]['override_method'](slotData.loc) then
                    return i
                end
            end

        -- Bonus Condition (triggers when bonus condition is not fulfilled)
        elseif MatchIDs[i]['bonus_condition'] then
            if name[slotData.itemId] then
                slotData['loc'] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
                if slotData['loc'] and slotData['loc']:IsValid() then
                    if not MatchIDs[i]['bonus_condition_method'](slotData.loc) then -- THERE IS A NOT HERE!
                        return i
                    end
                end
            end

        -- Standard ID Matching
        elseif name[slotData.itemId] then
            return i
        end
    end
end

function setFilter:GetOptions()
    return {
        movePreEvent = {
            name = "PreEvent",
            desc = "Items dropped in the Dragonflight Pre-Patch Event",
            type = "toggle",
            order = 10
        },

        showcoloredCategories = {
            name = "|cffff98abC|cffffa094o|cffffa77el|cffffaf67o|cfffebf71r|cfffecf7be|cfffddf85d|cffe0d988 |cffc3d38bC|cffa6cd8ea|cff9bccaet|cff8fcbcde|cff95bad2g|cff9aa9d7o|cffa098dcr|cffae98dci|cffbd98dce|cffcb98dcs|r",
            desc = "Should Categories be colored?",
            type = "toggle",
            order = 20
        },


    },
    AdiBags:GetOptionHandler(self, false, function ()
        return self:Update()
    end)
end
